---
title: About the project
---

# About the project

**Here you can find our core documents.**

Requirements engineering:
- [Requirements Specification _(legacy)_](/project/requirements-specification)
- [Project Plan _(legacy)_](/project/project-plan)
- [Use Cases](/project/use-cases)

Process engineering:
- [Process Model](/project/process-model)
- [Continuous Integration](/project/continuous-integration)

Project philosophy:
- [Project Philosophy](/project/project-philosophy)
